@@ -18,7 +18,7 @@
 //! ### Test that `cargo build -q` runs successfully and has empty output without normalization
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::cargo("build").arg("-q").run_pass(OutputStr::empty(), normalize::noop());
 //! ```
@@ -26,7 +26,7 @@
 //! ### Test that `rustc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::rustc().arg("-V").run_pass(
 //!    OutputStr::stdout_only("tests/ui/rustc_version.stdout"),
@@ -41,7 +41,7 @@
 //! ### Test that `rustdoc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::rustdoc().arg("-V").run_pass(
 //!    OutputStr::stdout_only("tests/ui/rustdoc_version.stdout"),
@@ -56,7 +56,7 @@
 //! ### Test that `clippy-driver -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::new("clippy-driver").rustc_like().arg("-V").run_pass(
 //!     OutputStr::stdout_only("tests/ui/clippy_version.stdout"),
@@ -71,7 +71,7 @@
 //! ### Test that `false` runs unsucessfully and has empty output without normalization
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::new("false").run_fail(OutputStr::empty(), normalize::noop());
 //! ```
@@ -79,7 +79,7 @@
 //! ### Test that `false garbage` also runs unsucessfully and has empty output without normalization
 //! ```
 //! use std::process::Command;
-//! use tryrun::{normalize, CommandExt, OutputStr};
+//! use tryrun::prelude::*;
 //!
 //! Command::new("false").arg("garbage").run_fail(OutputStr::empty(), normalize::noop());
 //! ```
@@ -123,7 +123,7 @@ pub trait Normalizer {
     ///
     /// The default implementation does not do any normalization:
     /// ```
-    /// # use tryrun::Normalizer;
+    /// # use tryrun::prelude::*;
     /// struct DefaultNormalizer;
     /// impl Normalizer for DefaultNormalizer {}
     /// assert_eq!(DefaultNormalizer.normalize_stdout(&mut b"foo".to_vec()), b"foo");
@@ -137,7 +137,7 @@ pub trait Normalizer {
     ///
     /// The default implementation does not do any normalization:
     /// ```
-    /// # use tryrun::Normalizer;
+    /// # use tryrun::prelude::*;
     /// struct DefaultNormalizer;
     /// impl Normalizer for DefaultNormalizer {}
     /// assert_eq!(DefaultNormalizer.normalize_stdout(&mut b"ar".to_vec()), b"ar");
@@ -195,7 +195,7 @@ mod normalizer {
 /// Implementation for mutable references.
 ///
 /// ```
-/// # use tryrun::{normalize, Normalizer};
+/// # use tryrun::prelude::*;
 /// fn assert_normalizer(_: impl Normalizer) {}
 /// assert_normalizer(&mut normalize::noop());
 /// ```
@@ -226,7 +226,7 @@ pub mod normalize {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::{normalize, Normalizer};
+    /// # use tryrun::prelude::*;
     /// let mut normalizer = normalize::noop();
     /// assert_eq!(normalizer.normalize_stdout(&mut b"foo".to_vec()), b"foo");
     /// assert!(normalizer.normalize_stdout(&mut Vec::new()).is_empty());
@@ -244,7 +244,7 @@ pub mod normalize {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::{normalize, Normalizer};
+    /// # use tryrun::prelude::*;
     /// let mut count: usize = 0;
     /// let mut normalizer = normalize::closure(|output| {
     ///     assert_eq!(output, b"foo");
@@ -265,7 +265,7 @@ pub mod normalize {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::{normalize, Normalizer};
+    /// # use tryrun::prelude::*;
     /// let mut flag = Some(());
     /// let mut normalizer = normalize::stdout(|output| {
     ///     assert_eq!(output, b"foo");
@@ -286,7 +286,7 @@ pub mod normalize {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::{normalize, Normalizer};
+    /// # use tryrun::prelude::*;
     /// let mut flag = Some(());
     /// let mut normalizer = normalize::stderr(|output| {
     ///     assert_eq!(output, b"foo");
@@ -358,7 +358,7 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::OutputStr;
+    /// # use tryrun::prelude::*;
     /// const EMPTY: OutputStr = OutputStr::empty();
     /// assert!(EMPTY.stdout.is_none());
     /// assert!(EMPTY.stderr.is_none());
@@ -376,7 +376,7 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::OutputStr;
+    /// # use tryrun::prelude::*;
     /// const STDOUT_ONLY: OutputStr = OutputStr::stdout_only("foo/bar.stdout");
     /// assert_eq!(STDOUT_ONLY.stdout.unwrap(), "foo/bar.stdout");
     /// assert!(STDOUT_ONLY.stderr.is_none());
@@ -394,7 +394,7 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
     ///
     /// ## Example
     /// ```
-    /// # use tryrun::OutputStr;
+    /// # use tryrun::prelude::*;
     /// const STDERR_ONLY: OutputStr = OutputStr::stderr_only("foo/bar.stderr");
     /// assert!(STDERR_ONLY.stdout.is_none());
     /// assert_eq!(STDERR_ONLY.stderr.unwrap(), "foo/bar.stderr");
@@ -413,7 +413,7 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
 ///
 /// ## Example
 /// ```
-/// # use tryrun::OutputStr;
+/// # use tryrun::prelude::*;
 /// OutputStr {
 ///     stdout: Some("a static string"),
 ///     stderr: Some("a static string"),
@@ -427,7 +427,7 @@ pub type OutputStr = Output<&'static str, &'static str>;
 ///
 /// # Example
 /// ```
-/// # use tryrun::OutputStr;
+/// # use tryrun::prelude::*;
 /// const STDOUT_STDERR: OutputStr = tryrun::output!(concat!(env!("OUT_DIR"), "/foo"));
 /// assert_eq!(STDOUT_STDERR.stdout.unwrap(), concat!(env!("OUT_DIR"), "/foo.stdout"));
 /// assert_eq!(STDOUT_STDERR.stderr.unwrap(), concat!(env!("OUT_DIR"), "/foo.stderr"));
@@ -720,6 +720,16 @@ impl CommandExt for Command {
     }
 }
 
+/// The prelude.
+///
+/// ```
+/// # #[allow(unused_imports)]
+/// use tryrun::prelude::*;
+/// ```
+pub mod prelude {
+    pub use super::{normalize, CommandExt as _, Normalizer, Output, OutputStr};
+}
+
 #[cfg(test)]
 mod tests {
     use super::{normalize, CommandExt, Normalizer, OutputStr};
